@@ -4,7 +4,6 @@ use std::pin::Pin;
 use std::task::{Context, Poll};
 
 use crate::runtime::{AsyncRead, AsyncWrite, TcpStream};
-use crate::url::Url;
 
 use self::Inner::*;
 
@@ -14,6 +13,8 @@ pub struct MaybeTlsStream {
 
 enum Inner {
     NotTls(TcpStream),
+    #[cfg(all(feature = "postgres", unix))]
+    UnixStream(crate::runtime::UnixStream),
     #[cfg(feature = "tls")]
     Tls(async_native_tls::TlsStream<TcpStream>),
     #[cfg(feature = "tls")]
@@ -21,8 +22,15 @@ enum Inner {
 }
 
 impl MaybeTlsStream {
-    pub async fn connect(url: &Url, default_port: u16) -> crate::Result<Self> {
-        let conn = TcpStream::connect((url.host(), url.port(default_port))).await?;
+    #[cfg(all(feature = "postgres", unix))]
+    pub async fn connect_uds<S: AsRef<std::ffi::OsStr>>(p: S) -> crate::Result<Self> {
+        let conn = crate::runtime::UnixStream::connect(p.as_ref()).await?;
+        Ok(Self {
+            inner: Inner::UnixStream(conn),
+        })
+    }
+    pub async fn connect(host: &str, port: u16) -> crate::Result<Self> {
+        let conn = TcpStream::connect((host, port)).await?;
         Ok(Self {
             inner: Inner::NotTls(conn),
         })
@@ -32,6 +40,8 @@ impl MaybeTlsStream {
     pub fn is_tls(&self) -> bool {
         match self.inner {
             Inner::NotTls(_) => false,
+            #[cfg(all(feature = "postgres", unix))]
+            Inner::UnixStream(_) => false,
             #[cfg(feature = "tls")]
             Inner::Tls(_) => true,
             #[cfg(feature = "tls")]
@@ -43,16 +53,20 @@ impl MaybeTlsStream {
     #[cfg_attr(docsrs, doc(cfg(feature = "tls")))]
     pub async fn upgrade(
         &mut self,
-        url: &Url,
+        host: &str,
         connector: async_native_tls::TlsConnector,
     ) -> crate::Result<()> {
         let conn = match std::mem::replace(&mut self.inner, Upgrading) {
             NotTls(conn) => conn,
+            #[cfg(all(feature = "postgres", unix))]
+            UnixStream(_) => {
+                return Err(tls_err!("TLS is not supported with unix domain sockets").into())
+            }
             Tls(_) => return Err(tls_err!("connection already upgraded").into()),
             Upgrading => return Err(tls_err!("connection already failed to upgrade").into()),
         };
 
-        self.inner = Tls(connector.connect(url.host(), conn).await?);
+        self.inner = Tls(connector.connect(host, conn).await?);
 
         Ok(())
     }
@@ -60,6 +74,8 @@ impl MaybeTlsStream {
     pub fn shutdown(&self, how: Shutdown) -> io::Result<()> {
         match self.inner {
             NotTls(ref conn) => conn.shutdown(how),
+            #[cfg(all(feature = "postgres", unix))]
+            UnixStream(ref conn) => conn.shutdown(how),
             #[cfg(feature = "tls")]
             Tls(ref conn) => conn.get_ref().shutdown(how),
             #[cfg(feature = "tls")]
@@ -73,6 +89,8 @@ macro_rules! forward_pin (
     ($self:ident.$method:ident($($arg:ident),*)) => (
         match &mut $self.inner {
             NotTls(ref mut conn) => Pin::new(conn).$method($($arg),*),
+            #[cfg(all(feature = "postgres", unix))]
+            UnixStream(ref mut conn) => Pin::new(conn).$method($($arg),*),
             #[cfg(feature = "tls")]
             Tls(ref mut conn) => Pin::new(conn).$method($($arg),*),
             #[cfg(feature = "tls")]
