@@ -1,8 +1,8 @@
 use crate::arguments::Arguments;
 use crate::encode::{Encode, IsNull};
-use crate::mysql::types::MySqlTypeInfo;
+use crate::mysql::type_info::MySqlTypeInfo;
 use crate::mysql::MySql;
-use crate::types::HasSqlType;
+use crate::types::Type;
 
 #[derive(Default)]
 pub struct MySqlArguments {
@@ -14,14 +14,6 @@ pub struct MySqlArguments {
 impl Arguments for MySqlArguments {
     type Database = MySql;
 
-    fn len(&self) -> usize {
-        self.param_types.len()
-    }
-
-    fn size(&self) -> usize {
-        self.params.len()
-    }
-
     fn reserve(&mut self, len: usize, size: usize) {
         self.param_types.reserve(len);
         self.params.reserve(size);
@@ -35,10 +27,10 @@ impl Arguments for MySqlArguments {
 
     fn add<T>(&mut self, value: T)
     where
-        Self::Database: HasSqlType<T>,
+        T: Type<Self::Database>,
         T: Encode<Self::Database>,
     {
-        let type_id = <MySql as HasSqlType<T>>::type_info();
+        let type_id = <T as Type<MySql>>::type_info();
         let index = self.param_types.len();
 
         self.param_types.push(type_id);
